@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2008 Index Data.
+ * Copyright (C) 1995-2010 Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -37,6 +37,7 @@
 
 YAZ_BEGIN_CDECL
 
+#if YAZ_HAVE_XML2
 /** \brief configures CCL bibset using XML configuration
     \param bibset CCL bibliographic profile
     \param ptr xml node pointer pointing to "cclmap" element
@@ -64,13 +65,14 @@ YAZ_BEGIN_CDECL
 YAZ_EXPORT
 int ccl_xml_config(CCL_bibset bibset, const xmlNode *ptr,
                    const char **addinfo);
-
+#endif
 YAZ_END_CDECL
 
 #endif
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
