@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data.
+ * Copyright (C) 1995-2010 Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -43,6 +43,19 @@ Z_RPNQuery *yaz_copy_z_RPNQuery(Z_RPNQuery *q, ODR out);
 YAZ_EXPORT
 Z_Query *yaz_copy_Z_Query(Z_Query *q, ODR out);
 
+YAZ_EXPORT
+Z_RPNQuery *yaz_clone_z_RPNQuery(Z_RPNQuery *q, NMEM out);
+
+YAZ_EXPORT
+Z_Query *yaz_clone_z_Query(Z_Query *q, NMEM out);
+
+YAZ_EXPORT
+Z_NamePlusRecord *yaz_clone_z_NamePlusRecord(Z_NamePlusRecord *s, NMEM out);
+
+YAZ_EXPORT
+Z_RecordComposition *yaz_clone_z_RecordComposition(Z_RecordComposition *s,
+                                                   NMEM out);
+
 YAZ_END_CDECL
 
 #endif
