@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data.
+ * Copyright (C) 1995-2010 Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -43,6 +43,33 @@ YAZ_BEGIN_CDECL
 /** \brief NMEM handle (an opaque pointer to memory) */
 typedef struct nmem_control *NMEM;
 
+/** \brief Set to 1 if YAZ BER integer is 64-bit ; 0 otherwise */
+#ifndef NMEM_64
+#define NMEM_64 1
+#endif
+
+#if NMEM_64
+
+#ifdef _MSC_VER
+/* Visual Studio. 6.0 and later supports this */
+typedef __int64 nmem_int_t;
+#define NMEM_INT_PRINTF "%I64d"
+#else
+/* C99 */
+typedef long long int nmem_int_t;
+#define NMEM_INT_PRINTF "%lld"
+#endif
+
+#else
+/** \brief BER/utility integer (32-bit on most platforms) */
+typedef int nmem_int_t;
+/** \brief printf format for nmem_int_t type */
+#define NMEM_INT_PRINTF "%d"
+#endif
+
+/** \brief BER/utility boolean */
+typedef int nmem_bool_t;
+
 /** \brief releases memory associaged with an NMEM handle 
     \param n NMEM handle
 */
@@ -51,7 +78,7 @@ YAZ_EXPORT void nmem_reset(NMEM n);
 /** \brief returns size in bytes of memory for NMEM handle
     \returns number of bytes
  */
-YAZ_EXPORT int nmem_total(NMEM n);
+YAZ_EXPORT size_t nmem_total(NMEM n);
 
 /** \brief allocates string on NMEM handle (similar strdup) 
     \param mem HNEM handle
@@ -94,12 +121,19 @@ YAZ_EXPORT void nmem_strsplit(NMEM nmem, const char *delim,
 YAZ_EXPORT void nmem_strsplit_blank(NMEM nmem, const char *dstr,
                                     char ***darray, int *num);
 
-/** \brief allocates integer for NMEM
+/** \brief allocates and sets integer for NMEM
     \param nmem NMEM handle
     \param v integer value
     \returns pointer to created integer
 */
-YAZ_EXPORT int *nmem_intdup(NMEM nmem, int v);
+YAZ_EXPORT nmem_int_t *nmem_intdup(NMEM nmem, nmem_int_t v);
+
+/** \brief allocates and sets boolean for NMEM
+    \param nmem NMEM handle
+    \param v value (0=false, != 0 true)
+    \returns pointer to created boolean
+*/
+YAZ_EXPORT nmem_bool_t *nmem_booldup(NMEM nmem, nmem_bool_t v);
 
 /** \brief transfers memory from one NMEM handle to another
     \param src source NMEM handle
@@ -122,7 +156,7 @@ YAZ_EXPORT void nmem_destroy(NMEM n);
     \param size number of bytes to be allocated
     \returns pointer to allocated memory
  */
-YAZ_EXPORT void *nmem_malloc(NMEM n, int size);
+YAZ_EXPORT void *nmem_malloc(NMEM n, size_t size);
 
 YAZ_END_CDECL
 
