@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data.
+ * Copyright (C) 1995-2010 Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -92,6 +92,11 @@ struct Z_External
 #define Z_External_multisrch2 26
 #define Z_External_CQL 27
 #define Z_External_OCLCUserInfo 28
+#define Z_External_persistentResultSet 29
+#define Z_External_persistentQuery 30
+#define Z_External_periodicQuerySchedule 31
+#define Z_External_exportSpecification 32
+#define Z_External_exportInvocation 33
     union
     {
         /* Generic types */
@@ -131,6 +136,12 @@ struct Z_External
         Z_MultipleSearchTerms_2 *multipleSearchTerms_2;
         Z_InternationalString *cql;
         Z_OCLC_UserInformation *oclc;
+        Z_PRPersistentResultSet *persistentResultSet;
+
+        Z_PQueryPersistentQuery *persistentQuery;
+        Z_PQSPeriodicQuerySchedule *periodicQuerySchedule;
+        Z_ESExportSpecification *exportSpecification;
+        Z_EIExportInvocation *exportInvocation;
     } u;
 };
 
