@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 /** 
@@ -79,14 +79,15 @@ int ccl_qual_field2(CCL_bibset bibset, const char *cp, const char *qual_name,
             /* lead is first of a list of qualifier aliaeses */
             /* qualifier alias: q1 q2 ... */
             char *qlist[10];
-            int i = 0;
+            size_t i = 0;
 
             qlist[i++] = lead_str;
 
-            while ((t=yaz_tok_move(tp)) == YAZ_TOK_STRING)
+            while (t == YAZ_TOK_STRING)
             {
                 if (i < sizeof(qlist)/sizeof(*qlist)-1)
                     qlist[i++] = xstrdup(yaz_tok_parse_string(tp));
+                t = yaz_tok_move(tp);
             }
             qlist[i] = 0;
             yaz_tok_parse_destroy(tp);
@@ -239,7 +240,7 @@ void ccl_qual_buf(CCL_bibset bibset, const char *buf)
     while (1)
     {
         const char *cp2 = cp1;
-        int len;
+        size_t len;
         while (*cp2 && !strchr("\r\n", *cp2))
             cp2++;
         len = cp2 - cp1;
