@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2008 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 /**
@@ -15,12 +15,12 @@
 #include <yaz/options.h>
 
 static int arg_no = 1;
-static int arg_off = 0;
+static size_t arg_off = 0;
 
 int options (const char *desc, char **argv, int argc, char **arg)
 {
     const char *opt_buf = 0;
-    int i = 0;
+    size_t i = 0;
     int ch = 0;
     
     if (arg_no >= argc)
@@ -55,7 +55,7 @@ int options (const char *desc, char **argv, int argc, char **arg)
         int type = 0;
         while (desc[i] == '{')
         {
-            int i0 = ++i;
+            size_t i0 = ++i;
             while (desc[i] && desc[i] != '}')
                 i++;
             if (opt_buf && (i - i0) == strlen(opt_buf) &&
@@ -66,7 +66,7 @@ int options (const char *desc, char **argv, int argc, char **arg)
         }
         if (desc[i] == ':')
         {       /* option with string argument */
-                type = desc[i++];
+            type = desc[i++];
         }
         if (desc_char == ch)
         { 
@@ -90,9 +90,7 @@ int options (const char *desc, char **argv, int argc, char **arg)
             }
             else /* option with no argument */
             {
-                if (argv[arg_no][arg_off])
-                    arg_off++;
-                else
+                if (!argv[arg_no][arg_off])
                 {
                     arg_off = 0;
                     arg_no++;
@@ -109,6 +107,7 @@ int options (const char *desc, char **argv, int argc, char **arg)
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
