@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 
@@ -18,6 +18,11 @@
 #include <yaz/z-core.h>
 #include <yaz/wrbuf.h>
 
+static void wrbuf_vputs(const char *buf, void *client_data)
+{
+    wrbuf_write((WRBUF) client_data, buf, strlen(buf));
+}
+
 static const char *lookup_index_from_string_attr(Z_AttributeList *attributes)
 {
     int j;
@@ -59,38 +64,39 @@ static const char *lookup_relation_index_from_attr(Z_AttributeList *attributes)
                 /* Only support for numeric relation */
                 Odr_int *relation = ae->value.numeric;
                 /* map this numeric to representation in CQL */
-                switch (*relation) {
+                switch (*relation)
+                {
                     /* Unsure on whether this is the relation attribute constants? */
-                    case Z_ProximityOperator_Prox_lessThan: 
-                        return "<";
-                    case Z_ProximityOperator_Prox_lessThanOrEqual: 
-                        return "<="; 
-                    case Z_ProximityOperator_Prox_equal: 
-                        return "="; 
-                    case Z_ProximityOperator_Prox_greaterThanOrEqual: 
-                        return ">="; 
-                    case Z_ProximityOperator_Prox_greaterThan: 
-                        return ">"; 
-                    case Z_ProximityOperator_Prox_notEqual: 
-                        return "<>"; 
-                    case 100: 
-                        /* phonetic is not supported in CQL */
-                        return 0; 
-                    case 101: 
-                        /* stem is not supported in CQL */
-                        return 0; 
-                    case 102: 
-                        /* relevance is supported in CQL, but not implemented yet */
-                        return 0; 
-                otherwise: 
-                        /* Invalid relation */
-                        return 0;
+                case Z_ProximityOperator_Prox_lessThan: 
+                    return "<";
+                case Z_ProximityOperator_Prox_lessThanOrEqual: 
+                    return "<="; 
+                case Z_ProximityOperator_Prox_equal: 
+                    return "="; 
+                case Z_ProximityOperator_Prox_greaterThanOrEqual: 
+                    return ">="; 
+                case Z_ProximityOperator_Prox_greaterThan: 
+                    return ">"; 
+                case Z_ProximityOperator_Prox_notEqual: 
+                    return "<>"; 
+                case 100: 
+                    /* phonetic is not supported in CQL */
+                    return 0; 
+                case 101: 
+                    /* stem is not supported in CQL */
+                    return 0; 
+                case 102: 
+                    /* relevance is supported in CQL, but not implemented yet */
+                    return 0; 
+                default:
+                    /* Invalid relation */
+                    return 0;
                 }
             }
             else {
                 /*  Can we have a complex relation value?
                     Should we implement something?
-                 */
+                */
             }
         }
     }
@@ -152,9 +158,9 @@ static int rpn2cql_attr(cql_transform_t ct,
 }
 
 /* Bug 2878: Currently only support left and right truncation. Specific check for this */
-static int checkForTruncation(int flag, Z_AttributeList *attributes) {
+static int checkForTruncation(int flag, Z_AttributeList *attributes)
+{
     int j;
-    int server_choice = 1;
     for (j = 0; j < attributes->num_attributes; j++)
     {
         Z_AttributeElement *ae = attributes->attributes[j];
@@ -162,10 +168,10 @@ static int checkForTruncation(int flag, Z_AttributeList *attributes) {
         {
             if (ae->which == Z_AttributeValue_numeric)
             {
-				int truncation = *(ae->value.numeric);
-        		/* This logic only works for Left, right and both. eg. 1,2,3 */
+                Odr_int truncation = *(ae->value.numeric);
+                /* This logic only works for Left, right and both. eg. 1,2,3 */
             	if (truncation <= 3)
-            		return (int) (truncation & flag);
+                    return ((int) truncation & flag);
             }
             /* Complex: Shouldn't happen */
         }
