@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data.
+ * Copyright (C) 1995-2010 Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -68,8 +68,6 @@ typedef enum {
 
 typedef struct request
 {
-    int len_refid;          /* length of referenceid */
-    char *refid;            /* referenceid */
     request_state state;
 
     Z_GDU *gdu_request;     /* Current request */
@@ -98,8 +96,8 @@ typedef struct request_q
  */
 typedef enum
 {
-    ASSOC_NEW,                /* not initialized yet */
-    ASSOC_UP,                 /* normal operation */
+    ASSOC_NEW,                /* not initialized yet or HTTP session */
+    ASSOC_UP,                 /* Z39.50 session is UP */
     ASSOC_DEAD                /* dead. Close if input arrives */
 } association_state;
 
@@ -122,13 +120,13 @@ typedef struct association
     association_state state;
 
     /* session parameters */
-    Odr_int preferredMessageSize;
-    Odr_int maximumRecordSize;
+    int preferredMessageSize;
+    int maximumRecordSize;
     int version;                  /* highest version-bit set (2 or 3) */
 
-    unsigned cs_get_mask;
-    unsigned cs_put_mask;
-    unsigned cs_accept_mask;
+    int cs_get_mask;
+    int cs_put_mask;
+    int cs_accept_mask;
 
     struct bend_initrequest *init;
     statserv_options_block *last_control;
