@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 /**
@@ -70,7 +70,7 @@
 #include <yaz/tcpip.h>
 #include <yaz/errno.h>
 
-static int tcpip_close(COMSTACK h);
+static void tcpip_close(COMSTACK h);
 static int tcpip_put(COMSTACK h, char *buf, int size);
 static int tcpip_get(COMSTACK h, char **buf, int *bufsize);
 static int tcpip_put_connect(COMSTACK h, char *buf, int size);
@@ -90,7 +90,7 @@ static int ssl_put(COMSTACK h, char *buf, int size);
 #endif
 
 static COMSTACK tcpip_accept(COMSTACK h);
-static char *tcpip_addrstr(COMSTACK h);
+static const char *tcpip_addrstr(COMSTACK h);
 static void *tcpip_straddr(COMSTACK h, const char *str);
 
 #if 0
@@ -206,7 +206,6 @@ COMSTACK tcpip_type(int s, int flags, int protocol, void *vp)
     p->state = s < 0 ? CS_ST_UNBND : CS_ST_IDLE; /* state of line */
     p->event = CS_NONE;
     p->cerrno = 0;
-    p->stackerr = 0;
     p->user = 0;
 
 #if HAVE_GNUTLS_H
@@ -636,27 +635,6 @@ int tcpip_rcvconnect(COMSTACK h)
 #define CERTF "ztest.pem"
 #define KEYF "ztest.pem"
 
-static void tcpip_setsockopt(int fd)
-{
-#if 0
-    int len = 4096;
-    int set = 1;
-    
-    if (setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char*)&set, sizeof(int)))
-    {
-        yaz_log(LOG_WARN|LOG_ERRNO, "setsockopt TCP_NODELAY");
-    }
-    if (setsockopt(fd, SOL_SOCKET, SO_SNDBUF, (char*)&len, sizeof(int)))
-    {
-        yaz_log(LOG_WARN|LOG_ERRNO, "setsockopt SNDBUF");
-    }
-    if (setsockopt(fd, SOL_SOCKET, SO_RCVBUF, (char*)&len, sizeof(int)))
-    {
-        yaz_log(LOG_WARN|LOG_ERRNO, "setsockopt RCVBUF");
-    }
-#endif
-}
-
 static int tcpip_bind(COMSTACK h, void *address, int mode)
 {
     int r;
@@ -746,7 +724,6 @@ static int tcpip_bind(COMSTACK h, void *address, int mode)
         return -1;
     }
 #endif
-    tcpip_setsockopt(h->iofile);
 #if HAVE_GETADDRINFO
     r = bind(h->iofile, ai->ai_addr, ai->ai_addrlen);
     freeaddrinfo(sp->ai);
@@ -774,8 +751,12 @@ int tcpip_listen(COMSTACK h, char *raddr, int *addrlen,
                  int (*check_ip)(void *cd, const char *a, int len, int t),
                  void *cd)
 {
+#ifdef WIN32
+    /* we don't get peer address on Windows (via accept) */
+#else
     struct sockaddr_in addr;
     YAZ_SOCKLEN_T len = sizeof(addr);
+#endif
 
     TRC(fprintf(stderr, "tcpip_listen pid=%d\n", getpid()));
     if (h->state != CS_ST_IDLE)
@@ -815,6 +796,10 @@ int tcpip_listen(COMSTACK h, char *raddr, int *addrlen,
         }
         return -1;
     }
+#ifdef WIN32
+    if (addrlen)
+        *addrlen = 0;
+#else
     if (addrlen && (size_t) (*addrlen) >= sizeof(struct sockaddr_in))
         memcpy(raddr, &addr, *addrlen = sizeof(struct sockaddr_in));
     else if (addrlen)
@@ -831,8 +816,8 @@ int tcpip_listen(COMSTACK h, char *raddr, int *addrlen,
         h->newfd = -1;
         return -1;
     }
+#endif
     h->state = CS_ST_INCON;
-    tcpip_setsockopt(h->newfd);
     return 0;
 }
 
@@ -1346,7 +1331,7 @@ int ssl_put(COMSTACK h, char *buf, int size)
 }
 #endif
 
-int tcpip_close(COMSTACK h)
+void tcpip_close(COMSTACK h)
 {
     tcpip_state *sp = (struct tcpip_state *)h->cprivate;
 
@@ -1406,10 +1391,9 @@ int tcpip_close(COMSTACK h)
     xfree(sp->connect_response_buf);
     xfree(sp);
     xfree(h);
-    return 0;
 }
 
-char *tcpip_addrstr(COMSTACK h)
+const char *tcpip_addrstr(COMSTACK h)
 {
     tcpip_state *sp = (struct tcpip_state *)h->cprivate;
     char *r = 0, *buf = sp->buf;
