@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2008 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 
@@ -65,13 +65,13 @@ int main(int argc, char **argv)
         {
             int j;
             printf ("%s\n", ZOOM_connection_option_get(z[i], "host"));
-            for (j = 0; j<ZOOM_scanset_size (s[i]); j++)
+            for (j = 0; j < (int) ZOOM_scanset_size (s[i]); j++)
             {
-                int occur, len;
+                size_t occur, len;
                 const char *term;
                 term = ZOOM_scanset_term (s[i], j, &occur, &len);
                 if (term)
-                    printf ("%d %.*s %d\n", j, len, term, occur);
+                    printf ("%d %.*s %d\n", j, (int) len, term, (int) occur);
             }
         }
     }
@@ -88,6 +88,7 @@ int main(int argc, char **argv)
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
